@@ -48,6 +48,10 @@ setConstructorS3("Arguments", function(...) {
 #  otherwise an exception is thrown.
 # }
 #
+# \section{Missing values}{
+#   If \code{filename} is a missing value, then an exception is thrown.
+# }
+#
 # \details{
 #   When argument \code{class="safe"}, the following 86 ASCII characters
 #   are allowed in filenames:
@@ -99,6 +103,9 @@ setMethodS3("getFilename", "Arguments", function(static, filename, nchar=c(1,128
   }
 
   # Argument 'filename':
+  if (is.na(filename)) {
+    throw("Argument 'filename' cannot be a missing value: ", filename)
+  }
   filename <- getCharacter(static, filename, nchar=nchar, .name=.name);
 
   # Argument 'class':
@@ -126,7 +133,7 @@ setMethodS3("getFilename", "Arguments", function(static, filename, nchar=c(1,128
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Check for remaining (=invalid) characters
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  if (nchar(chars) > 0) {
+  if (nchar(chars, type="chars") > 0L) {
     chars <- unlist(strsplit(chars, split=""));
     chars <- sort(unique(chars));
     chars <- sprintf("'%s'", chars);
@@ -251,8 +258,8 @@ setMethodS3("getReadablePathname", "Arguments", function(static, file=NULL, path
   # https://msdn.microsoft.com/en-us/library/aa365247(VS.85).aspx
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (.Platform$OS.type == "windows") {
-    if (nchar(pathname) > 255L) {
-      msg <- sprintf("A too long pathname (%d characters) was detected on Windows, where maximum number of symbols is 256 and in R it is one less: %s", nchar(pathname), pathname);
+    if (!is.na(pathname) && nchar(pathname, type="chars") > 255L) {
+      msg <- sprintf("A too long pathname (%d characters) was detected on Windows, where maximum number of symbols is 256 and in R it is one less: %s", nchar(pathname, type="chars"), pathname);
       warning(msg);
     }
   }
@@ -297,8 +304,8 @@ setMethodS3("getReadablePathname", "Arguments", function(static, file=NULL, path
   # https://msdn.microsoft.com/en-us/library/aa365247(VS.85).aspx
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (.Platform$OS.type == "windows") {
-    if (nchar(pathname) > 255L) {
-      msg <- sprintf("A too long pathname (%d characters) was detected on Windows, where maximum number of symbols is 256 and in R it is one less: %s", nchar(pathname), pathname);
+    if (!is.na(pathname) && nchar(pathname, type="chars") > 255L) {
+      msg <- sprintf("A too long pathname (%d characters) was detected on Windows, where maximum number of symbols is 256 and in R it is one less: %s", nchar(pathname, type="chars"), pathname);
       warning(msg);
     }
   }
@@ -327,13 +334,10 @@ setMethodS3("getReadablePathname", "Arguments", function(static, file=NULL, path
       } else {
         reason <- sprintf("%s/ exists, but nothing beyond", parent);
       }
-      if (!is.null(reason))
-        if (!isAbsolutePath(pathname)) {
-          reason <- sprintf("%s; current directory is '%s'", reason, getwd());
-        }
-        reason <- sprintf(" (%s)", reason);
-      mprint(getwd())
-      mprint(dir())
+      if (!is.null(reason) && !isAbsolutePath(pathname)) {
+        reason <- sprintf("%s; current directory is '%s'", reason, getwd());
+      }
+      reason <- sprintf(" (%s)", reason);
       throw("Pathname not found: ", pathname, reason);
     }
 
@@ -437,7 +441,8 @@ setMethodS3("getReadablePathnames", "Arguments", function(static, files=NULL, pa
 #   \item{mkdirs}{If @TRUE, \code{mustNotExist} is @FALSE, and the path to
 #     the file does not exist, it is (recursively) created.}
 #   \item{maxTries}{A positive @integer specifying how many times the
-#     method should try to create a missing directory before giving up.}
+#     method should try to create a missing directory before giving up.
+#     For more details, see @see "R.utils::mkdirs".}
 # }
 #
 # \value{
@@ -449,18 +454,6 @@ setMethodS3("getReadablePathnames", "Arguments", function(static, files=NULL, pa
 #   If any argument in \code{...} is @NA, an exception is thrown.
 # }
 #
-# \section{Slow file systems}{
-#   On very rare occassions, we have observed on a large shared file
-#   system that if one tests for the existance of a directory immediately
-#   after creating it with @see "base::dir.create", it may appear not
-#   to be created.  We believe this is due to the fact that there is a
-#   short delay between creating a directory and that information being
-#   fully propagated on the file system.  To minimize the risk for such
-#   false assertions on "slow" file systems, this method tries to create
-#   a missing directory multiple times (argument \code{maxTries}) (while
-#   waiting a short period of time between each round) before giving up.
-# }
-#
 # @author
 #
 # \seealso{
@@ -519,31 +512,8 @@ setMethodS3("getWritablePathname", "Arguments", function(static, ..., mustExist=
         pathnameP <- getWritablePathname(static, file="dummy-not-tested", path=pathP, mustExist=FALSE, mustNotExist=FALSE, mkdirs=TRUE, maxTries=maxTries);
       }
 
-      # Argument 'maxTries':
-      maxTries <- getInteger(static, maxTries, range=c(1L,100L));
-
       # Try to create the directory
-      res <- FALSE;
-      for (tt in 1:maxTries) {
-        mkdirs(path);
-        # Succeeded?
-        res <- isDirectory(path);
-        if (res) break;
-        # If not, wait a bit and try again...
-        Sys.sleep(0.5);
-      } # for (tt in ...)
-
-      if (!res) {
-        # Check if file permissions allow to create a directory
-        pathP <- ifelse(is.null(pathP), ".", pathP);
-        if (fileAccess(pathP, mode=2) == -1) {
-          reason <- ", most likely because of lack of file permissions";
-        } else {
-          reason <- " for unknown reasons"
-        }
-
-        throw(sprintf("Failed not create file path (tried %d time(s))%s (%s %s but nothing beyond; current directory is '%s'): %s", maxTries, reason, pathP, ifelse(createParent, "was created", "exists"), getwd(), path));
-      }
+      mkdirs(path, mustWork=TRUE, maxTries=maxTries)
     }
 
     filename <- basename(pathname);
@@ -623,10 +593,7 @@ setMethodS3("getDirectory", "Arguments", function(static, path=NULL, ..., mustEx
     throw("Directory does not exist: ", pathname);
   }
 
-  mkdirs(pathname);
-  if (!isDirectory(pathname)) {
-    throw("Failed to create directory (recursively): ", pathname);
-  }
+  mkdirs(pathname, mustWork=TRUE)
 
   pathname;
 }, static=TRUE, protected=TRUE)
@@ -740,6 +707,11 @@ setMethodS3("getVector", "Arguments", function(static, x, length=NULL, .name=NUL
 #  thrown.
 # }
 #
+# \section{Missing values}{
+#   If \code{s} contains missing values, and \code{nchar} is not @NULL,
+#   then an exception is thrown.
+# }
+#
 # @author
 #
 # \seealso{
@@ -788,12 +760,17 @@ setMethodS3("getCharacters", "Arguments", function(static, s, length=NULL, trim=
   if (is.null(nchar))
     return(s);
 
+  # At this point, missing values are not allowed
+  if (any(is.na(s))) {
+    throw("Argument 'nchar' cannot be specified if character vector contains missing values: ", hpaste(sQuote(s)))
+  }
+
   if (length(nchar) == 1L)
     nchar <- c(1L, nchar);
 
   # Check the string length of each character string
   for (kk in seq(length=length(s))) {
-    slen <- nchar(s[kk]);
+    slen <- nchar(s[kk], type="chars");
     if (slen < nchar[1L] || slen > nchar[2L]) {
       throw(sprintf("String length of elements #%d in '%s' is out of range [%d,%d]: %d '%s'", kk, .name, nchar[1L], nchar[2L], slen, s[kk]));
     }
